@@ -1,9 +1,11 @@
+# shadowstep/terminal/__init__.py
+
 from shadowstep.terminal.adb import Adb
 from shadowstep.terminal.terminal import Terminal
 from shadowstep.terminal.transport import Transport
 
 __all__ = [
-    'Adb',
-    'Terminal',
-    'Transport',
+    "Adb",
+    "Terminal",
+    "Transport",
 ]
